@@ -19,9 +19,9 @@ def cancel_function(json_message):
 
 try:
     auto_solve = AutoSolve({
-        "access_token" : "30144-4a843021-bb26-4a13-b442-f7ce4824da14",
-        "api_key" : "2164d024-51a9-4401-a8f6-23a08e46d314",
-        "client_key" : "Testing-32f4dd15-11a9-4b4b-97f3-5f3b94063609",
+        "access_token": "clientAccessToken",
+        "api_key": "clientApiKey",
+        "client_key": "yourClientKey",
         "receiver_function" : receiver_function,
         "cancel_function" : cancel_function,
         "debug" : True
